package javax.xml.validation;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.security.PrivilegedActionException;
import java.security.PrivilegedExceptionAction;
import java.util.Enumeration;

final class SecuritySupport {
  static ClassLoader getContextClassLoader() { return (ClassLoader)AccessController.doPrivileged(new PrivilegedAction() {
          public Object run() {
            ClassLoader classLoader = null;
            try {
              classLoader = Thread.currentThread().getContextClassLoader();
            } catch (SecurityException securityException) {}
            return classLoader;
          }
        }); }
  
  static String getSystemProperty(final String propName) { return (String)AccessController.doPrivileged(new PrivilegedAction() {
          public Object run() { return System.getProperty(propName); }
        }); }
  
  static FileInputStream getFileInputStream(final File file) throws FileNotFoundException {
    try {
      return (FileInputStream)AccessController.doPrivileged(new PrivilegedExceptionAction() {
            public Object run() { return new FileInputStream(file); }
          });
    } catch (PrivilegedActionException privilegedActionException) {
      throw (FileNotFoundException)privilegedActionException.getException();
    } 
  }
  
  static InputStream getURLInputStream(final URL url) throws IOException {
    try {
      return (InputStream)AccessController.doPrivileged(new PrivilegedExceptionAction() {
            public Object run() { return url.openStream(); }
          });
    } catch (PrivilegedActionException privilegedActionException) {
      throw (IOException)privilegedActionException.getException();
    } 
  }
  
  static URL getResourceAsURL(final ClassLoader cl, final String name) { return (URL)AccessController.doPrivileged(new PrivilegedAction() {
          public Object run() {
            URL uRL;
            if (cl == null) {
              uRL = ClassLoader.getSystemResource(name);
            } else {
              uRL = cl.getSystemResource(name);
            } 
            return uRL;
          }
        }); }
  
  static Enumeration getResources(final ClassLoader cl, final String name) throws IOException {
    try {
      return (Enumeration)AccessController.doPrivileged(new PrivilegedExceptionAction() {
            public Object run() {
              Enumeration enumeration;
              if (cl == null) {
                enumeration = ClassLoader.getSystemResources(name);
              } else {
                enumeration = cl.getSystemResources(name);
              } 
              return enumeration;
            }
          });
    } catch (PrivilegedActionException privilegedActionException) {
      throw (IOException)privilegedActionException.getException();
    } 
  }
  
  static InputStream getResourceAsStream(final ClassLoader cl, final String name) { return (InputStream)AccessController.doPrivileged(new PrivilegedAction() {
          public Object run() {
            InputStream inputStream;
            if (cl == null) {
              inputStream = ClassLoader.getSystemResourceAsStream(name);
            } else {
              inputStream = cl.getResourceAsStream(name);
            } 
            return inputStream;
          }
        }); }
  
  static boolean doesFileExist(final File f) { return ((Boolean)AccessController.doPrivileged(new PrivilegedAction() {
          public Object run() { return f.exists() ? Boolean.TRUE : Boolean.FALSE; }
        })).booleanValue(); }
}


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\xml-apis.jar!\javax\xml\validation\SecuritySupport.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       1.0.7
 */