package javax.xml.transform;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.util.Properties;

final class FactoryFinder {
  private static boolean debug = false;
  
  static Properties cacheProps = new Properties();
  
  static boolean firstTime = true;
  
  private static final int DEFAULT_LINE_LENGTH = 80;
  
  private static void dPrint(String paramString) {
    if (debug)
      System.err.println("JAXP: " + paramString); 
  }
  
  private static Object newInstance(String paramString, ClassLoader paramClassLoader, boolean paramBoolean) throws ConfigurationError {
    try {
      Class clazz;
      if (paramClassLoader == null) {
        clazz = Class.forName(paramString);
      } else {
        try {
          clazz = paramClassLoader.loadClass(paramString);
        } catch (ClassNotFoundException classNotFoundException) {
          if (paramBoolean) {
            paramClassLoader = FactoryFinder.class.getClassLoader();
            if (paramClassLoader != null) {
              clazz = paramClassLoader.loadClass(paramString);
            } else {
              clazz = Class.forName(paramString);
            } 
          } else {
            throw classNotFoundException;
          } 
        } 
      } 
      Object object = clazz.newInstance();
      if (debug)
        dPrint("created new instance of " + clazz + " using ClassLoader: " + paramClassLoader); 
      return object;
    } catch (ClassNotFoundException classNotFoundException) {
      throw new ConfigurationError("Provider " + paramString + " not found", classNotFoundException);
    } catch (Exception exception) {
      throw new ConfigurationError("Provider " + paramString + " could not be instantiated: " + exception, exception);
    } 
  }
  
  static Object find(String paramString1, String paramString2) throws ConfigurationError {
    ClassLoader classLoader = SecuritySupport.getContextClassLoader();
    if (classLoader == null)
      classLoader = FactoryFinder.class.getClassLoader(); 
    if (debug)
      dPrint("find factoryId =" + paramString1); 
    try {
      String str = SecuritySupport.getSystemProperty(paramString1);
      if (str != null) {
        if (debug)
          dPrint("found system property, value=" + str); 
        return newInstance(str, classLoader, true);
      } 
    } catch (SecurityException securityException) {}
    try {
      String str1 = SecuritySupport.getSystemProperty("java.home");
      String str2 = str1 + File.separator + "lib" + File.separator + "jaxp.properties";
      String str3 = null;
      if (firstTime)
        synchronized (cacheProps) {
          if (firstTime) {
            File file = new File(str2);
            firstTime = false;
            if (SecuritySupport.doesFileExist(file)) {
              if (debug)
                dPrint("Read properties file " + file); 
              cacheProps.load(SecuritySupport.getFileInputStream(file));
            } 
          } 
        }  
      str3 = cacheProps.getProperty(paramString1);
      if (str3 != null) {
        if (debug)
          dPrint("found in $java.home/jaxp.properties, value=" + str3); 
        return newInstance(str3, classLoader, true);
      } 
    } catch (Exception exception) {
      if (debug)
        exception.printStackTrace(); 
    } 
    Object object = findJarServiceProvider(paramString1);
    if (object != null)
      return object; 
    if (paramString2 == null)
      throw new ConfigurationError("Provider for " + paramString1 + " cannot be found", null); 
    if (debug)
      dPrint("loaded from fallback value: " + paramString2); 
    return newInstance(paramString2, classLoader, true);
  }
  
  private static Object findJarServiceProvider(String paramString) throws ConfigurationError {
    String str1 = "META-INF/services/" + paramString;
    InputStream inputStream = null;
    ClassLoader classLoader = SecuritySupport.getContextClassLoader();
    if (classLoader != null) {
      inputStream = SecuritySupport.getResourceAsStream(classLoader, str1);
      if (inputStream == null) {
        classLoader = FactoryFinder.class.getClassLoader();
        inputStream = SecuritySupport.getResourceAsStream(classLoader, str1);
      } 
    } else {
      classLoader = FactoryFinder.class.getClassLoader();
      inputStream = SecuritySupport.getResourceAsStream(classLoader, str1);
    } 
    if (inputStream == null)
      return null; 
    if (debug)
      dPrint("found jar resource=" + str1 + " using ClassLoader: " + classLoader); 
    try {
      bufferedReader = new BufferedReader(new InputStreamReader(inputStream, "UTF-8"), 80);
    } catch (UnsupportedEncodingException unsupportedEncodingException) {
      bufferedReader = new BufferedReader(new InputStreamReader(inputStream), 80);
    } 
    String str2 = null;
    try {
      str2 = bufferedReader.readLine();
    } catch (IOException iOException) {
      return null;
    } finally {
      try {
        bufferedReader.close();
      } catch (IOException iOException) {}
    } 
    if (str2 != null && !"".equals(str2)) {
      if (debug)
        dPrint("found in resource, value=" + str2); 
      return newInstance(str2, classLoader, false);
    } 
    return null;
  }
  
  static  {
    try {
      String str = SecuritySupport.getSystemProperty("jaxp.debug");
      debug = (str != null && !"false".equals(str));
    } catch (SecurityException securityException) {
      debug = false;
    } 
  }
  
  static class ConfigurationError extends Error {
    private Exception exception;
    
    ConfigurationError(String param1String, Exception param1Exception) {
      super(param1String);
      this.exception = param1Exception;
    }
    
    Exception getException() { return this.exception; }
  }
}


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\xml-apis.jar!\javax\xml\transform\FactoryFinder.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       1.0.7
 */